function FindProjectItems
{
    function FindProjectItemsRecurse
    {
        param ( $RelativePath = '.\',  $ProjectItem, $ProjPath )
 
        $projItemFolder = '{6BB5F8EF-4483-11D3-8BCF-00C04F8EC28C}' # Visual Studio defined constant
        
        if ($ProjectItem.Kind -eq $projItemFolder -and $ProjectItem.ProjectItems -ne $null)
        {
            $relativeFolderPath = Join-Path -Path $RelativePath -ChildPath $ProjectItem.Name
            $ProjectItem.ProjectItems | 
                ForEach-Object {FindProjectItemsRecurse -RelativePath $relativeFolderPath -ProjectItem $_ -ProjPath $ProjPath }
        }
        else
        {
            $relativeFileName = Join-Path -Path $RelativePath -ChildPath $ProjectItem.Name                       
            $fileName = Join-Path -Path $ProjPath -ChildPath $relativeFileName;
            $ProjectItem |
                    Add-Member -MemberType NoteProperty -Name FileName -Value $fileName -PassThru
        }
    }

    $DTE.Solution.Projects | ForEach {
	    $proj = $_
	    if ($proj.FileName -ne $null -and $proj.FileName -ne '')
        {
            $projPath = Split-Path -Path $proj.FileName -Parent
            $proj.ProjectItems | 
                        ForEach-Object { FindProjectItemsRecurse -ProjectItem $_ -ProjPath $projPath }
        }
    }
    }

function Get-CodeLineCount($TypeOfCode) {
    $CodeFileExtension = "*{0}" -f $TypeOfCode
    # Get the file contents for the files that match our type
    $fileContents = FindProjectItems | 
                        Where { $_.FileName -ne $null -and $_.FileName -ne '' -and $_.FileName -like $CodeFileExtension } | 
                        ForEach { Get-Content -LiteralPath $_.FileName}
    #Trim blank lines and measure
    $lineCount =  $fileContents | 
                        Where { $_ -ne ''} | 
                        Measure-Object

    $message = "You have {0} lines of code" -f $lineCount.Count
    echo $message
    
    #Speak the message - coz we can
    $speak = new-object -com "SAPI.SPVOICE"
    $ret = $speak.Speak($message)
}


Register-TabExpansion 'Get-CodeLineCount' @{
    'TypeOfCode' = { FindProjectItems | 
                        Where { $_.FileName -ne $null -and $_.FileName -ne ''} | 
                        ForEach-Object {[System.IO.Path]::GetExtension($_.FileName)} | 
                        Group-Object | 
                        Select -ExpandProperty Name }
    
}



Export-ModuleMember Get-CodeLineCount
